/* BdfServer_Commands - Copyright (c) 2018-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.util.HashMap;
import java.util.Map;
import net.fichotheque.MetadataEditor;
import net.fichotheque.utils.FichothequeUtils;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelChange;


/**
 *
 * @author Vincent Calame
 */
public abstract class AbstractPhrasesCommand extends AbstractBdfCommand {

    public final static String TITLE_PARAMPREFIX = "title/";
    public final static String NEWPHRASE_PARAMNAME = "newphrase";
    public final static String NEWPHRASE_PARAMPREFIX = "newphrase/";
    private final Map<String, LabelChange> phraseChangeMap = new HashMap<String, LabelChange>();
    private LabelChange titleLabelChange;
    private String newPhraseName;
    private LabelChange newPhraseLabelChange;

    public AbstractPhrasesCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    protected boolean update(MetadataEditor metadataEditor) {
        boolean done = false;
        if (changeLabels(metadataEditor, null, titleLabelChange)) {
            done = true;
        }
        for (Map.Entry<String, LabelChange> entry : phraseChangeMap.entrySet()) {
            if (changeLabels(metadataEditor, entry.getKey(), entry.getValue())) {
                done = true;
            }
        }
        if (newPhraseName != null) {
            if (changeLabels(metadataEditor, newPhraseName, newPhraseLabelChange)) {
                done = true;
            }
        }
        return done;
    }

    protected boolean checkPhrasesParameters() {
        newPhraseName = requestMap.getParameter(NEWPHRASE_PARAMNAME);
        if (newPhraseName != null) {
            newPhraseName = newPhraseName.trim();
            if (newPhraseName.length() > 0) {
                if (FichothequeUtils.isValidPhraseName(newPhraseName)) {
                    newPhraseLabelChange = BdfCommandUtils.getLabelChange(requestMap, NEWPHRASE_PARAMPREFIX, true);
                } else {
                    setError("_ error.wrong.phrasename", newPhraseName);
                    newPhraseName = null;
                    return false;
                }
            } else {
                newPhraseName = null;
            }
        }
        titleLabelChange = BdfCommandUtils.getLabelChange(requestMap, TITLE_PARAMPREFIX, true);
        for (String paramName : requestMap.getParameterNameSet()) {
            if (paramName.startsWith("phrase_")) {
                String phraseName = paramName.substring("phrase_".length());
                int idx = phraseName.indexOf('/');
                if (idx > 0) {
                    phraseName = phraseName.substring(0, idx);
                    LabelChange phraseChange = BdfCommandUtils.getLabelChange(requestMap, BdfInstructionUtils.getPhraseParamPrefix(phraseName), true);
                    phraseChangeMap.put(phraseName, phraseChange);
                }
            }
        }
        return true;
    }

    private static boolean changeLabels(MetadataEditor metadataEditor, String name, LabelChange labelChange) {
        boolean done = false;
        for (Label label : labelChange.getChangedLabels()) {
            boolean stepdone = metadataEditor.putLabel(name, label);
            if (stepdone) {
                done = true;
            }
        }
        for (Lang lang : labelChange.getRemovedLangList()) {
            boolean stepdone = metadataEditor.removeLabel(name, lang);
            if (stepdone) {
                done = true;
            }
        }
        return done;
    }

    public static String getParamPrefix(String phraseName) {
        return "phrase_" + phraseName + "/";
    }

}
