/* BdfServer_Commands - Copyright (c) 2010-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.album;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.util.HashMap;
import java.util.Map;
import net.fichotheque.album.Album;
import net.fichotheque.album.AlbumConstants;
import net.fichotheque.album.metadata.AlbumDim;
import net.fichotheque.album.metadata.AlbumMetadataEditor;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class DimUsageChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "DimUsageChange";
    public final static String COMMANDKEY = "_ ALB-06";
    public final static String VIGNETTE_PARAMNAME = "vignette";
    public final static String DETAIL_PARAMNAME = "detail";
    private final Map<String, AlbumDim> usageMap = new HashMap<String, AlbumDim>();
    private Album album;

    public DimUsageChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.ALBUM + "/" + COMMANDNAME);
        AlbumMetadataEditor albumMetadataEditor = editSession.getFichothequeEditor().getAlbumEditor(album.getSubsetKey()).getAlbumMetadataEditor();
        boolean done = false;
        for (Map.Entry<String, AlbumDim> entry : usageMap.entrySet()) {
            String usageName = entry.getKey();
            AlbumDim albumDim = entry.getValue();
            boolean done2 = albumMetadataEditor.setAlbumDimForUsage(usageName, albumDim);
            if (done2) {
                done = true;
            }
        }
        if (done) {
            setDone("_ done.album.dimusagechange");
        }
        putResultObject(ALBUM_OBJ, album);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        album = BdfInstructionUtils.getMandatoryAlbum(fichotheque, requestMap);
        checkSubsetAdminPermission(album);
        String vignetteName = getMandatory(VIGNETTE_PARAMNAME).trim();
        String detailName = getMandatory(DETAIL_PARAMNAME).trim();
        AlbumDim vignetteDim = null;
        AlbumDim detailDim = null;
        if (vignetteName.length() > 0) {
            vignetteDim = album.getAlbumMetadata().getAlbumDimByName(vignetteName);
        }
        if (detailName.length() > 0) {
            detailDim = album.getAlbumMetadata().getAlbumDimByName(detailName);
        }
        usageMap.put(AlbumConstants.VIGNETTE_USAGE, vignetteDim);
        usageMap.put(AlbumConstants.DETAIL_USAGE, detailDim);
        return true;
    }

}
