/* BdfServer_Commands - Copyright (c) 2011-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.corpus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.ui.UiComponents;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.text.ParseException;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.include.ExtendedIncludeKey;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class IncludeRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "IncludeRemove";
    public final static String COMMANDKEY = "_ CRP-14";
    public final static String KEY_PARAMNAME = "key";
    private Corpus corpus;
    private String name;
    private UiComponents uiComponents;

    public IncludeRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() {
        putResultObject(CORPUS_OBJ, corpus);
        BdfServerEditor bdfServerEditor = bdfServer.getBdfServerEditor();
        boolean done = bdfServerEditor.removeComponentUi(uiComponents, name);
        if (done) {
            bdfServerEditor.saveChanges();
            setDone("_ done.corpus.includeremove", name);
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        corpus = BdfInstructionUtils.getMandatoryCorpus(fichotheque, requestMap);
        checkSubsetAdminPermission(corpus);
        String key = getMandatory(KEY_PARAMNAME);
        try {
            ExtendedIncludeKey includeKey = ExtendedIncludeKey.parse(key);
            name = includeKey.toString();
        } catch (ParseException pe) {
            throw new BdfInstructionException(BdfInstructionUtils.wrongParameterValue(KEY_PARAMNAME, key));
        }
        uiComponents = bdfServer.getUiManager().getMainUiComponents(corpus);
        if (uiComponents.getUiComponent(name) == null) {
            throw new BdfInstructionException(BdfInstructionUtils.unknownParameterValue(KEY_PARAMNAME, key));
        }
        return true;
    }

}
