/* BdfServer_Commands - Copyright (c) 2010-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.edition;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.EditionEngine;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.corpus.FicheMeta;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class FicheIndexationChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "FicheIndexationChange";
    private FicheMeta ficheMeta;

    public FicheIndexationChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.EDITION + "/" + COMMANDNAME);
        EditionEngine.croisementOnly(editSession, bdfUser, getPermissionSummary(), requestMap)
                .updateFiche(ficheMeta);
        setDone("_ done.edition.ficheindexationchange");
        putResultObject(CORPUS_OBJ, ficheMeta.getCorpus());
        putResultObject(FICHEMETA_OBJ, ficheMeta);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        ficheMeta = BdfInstructionUtils.getMandatoryFicheMeta(fichotheque, requestMap);
        checkSubsetAdminPermission(ficheMeta.getCorpus());
        return true;
    }

}
