/* BdfServer - Copyright (c) 2008-2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.storage.directory.oldversions;

import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.api.configuration.LangConfiguration;
import fr.exemole.bdfserver.tools.configuration.LangConfigurationBuilder;
import java.text.ParseException;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.xml.ElementHandler;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class ConfigurationManagerDOMReader {

    private final MessageHandler messageHandler;
    private BdfServerEditor bdfServerEditor;

    public ConfigurationManagerDOMReader(MessageHandler messageHandler) {
        this.messageHandler = messageHandler;
    }

    public void readConfigurationManager(BdfServerEditor bdfServerEditor, Element element_xml) {
        this.bdfServerEditor = bdfServerEditor;
        DOMUtils.readChildren(element_xml, new RootHandler());
    }


    private class RootHandler implements ElementHandler {

        private RootHandler() {
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("lang-config")) {
                LangConfigHandler langConfigHandler = new LangConfigHandler();
                DOMUtils.readChildren(element, langConfigHandler);
                bdfServerEditor.setLangConfiguration(langConfigHandler.toLangConfiguration());
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }


    private class LangConfigHandler implements ElementHandler {

        private final LangConfigurationBuilder langConfigurationBuilder = new LangConfigurationBuilder();

        private LangConfigHandler() {
            langConfigurationBuilder.setAllLanguages(false);
        }

        public LangConfiguration toLangConfiguration() {
            return langConfigurationBuilder.toLangConfiguration();
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("all-languages")) {
                langConfigurationBuilder.setAllLanguages(true);
            } else if (tagName.equals("with-original-name")) {
                langConfigurationBuilder.setWithNonlatin(true);
            } else if (tagName.equals("working-lang")) {
                try {
                    Lang lang = Lang.parse(element.getAttribute("lang"));
                    langConfigurationBuilder.addWorkingLang(lang);
                } catch (ParseException pe) {
                }
            } else if (tagName.equals("supplementary-lang")) {
                try {
                    Lang langInteger = Lang.parse(element.getAttribute("lang"));
                    langConfigurationBuilder.addSupplementaryLang(langInteger);
                } catch (ParseException pe) {
                }
            } else if (tagName.equals("without-nom-avant")) {
                langConfigurationBuilder.setWithoutSurnameFirst(true);
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }

}
