/* BdfServer_HtmlProducers - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.exportation;

import fr.exemole.bdfserver.api.balayage.Balayage;
import fr.exemole.bdfserver.api.balayage.BalayageMode;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.ExportationDomain;
import fr.exemole.bdfserver.commands.exportation.BalayageRunCommand;
import fr.exemole.bdfserver.tools.BH;
import fr.exemole.bdfserver.tools.BdfHref;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlAttributes;
import net.mapeadores.util.html.HtmlPrinter;


/**
 *
 * @author Vincent Calame
 */
public final class ExportationHtmlUtils {

    private ExportationHtmlUtils() {
    }

    public static boolean printBalayageLinks(HtmlPrinter hp, Balayage balayage, String target) {
        HtmlAttributes aAttr = HA.href("").target(target);
        String balayageName = balayage.getName();
        hp
                .A(aAttr.href(balayageHref(balayageName)))
                .__escape(balayage.getName())
                ._A();
        int count = balayage.getBalayageModeCount();
        if (count > 0) {
            hp
                    .__space()
                    .SMALL()
                    .__escape('[');
            for (int i = 0; i < count; i++) {
                BalayageMode balayageMode = balayage.getBalayageMode(i);
                String modeName = balayageMode.getName();
                if (i != 0) {
                    hp
                            .__escape(" | ");
                }
                hp
                        .A(aAttr.href(balayageHref(balayageName).param(BalayageRunCommand.MODE_PARAMNAME, modeName)))
                        .__escape(modeName)
                        ._A();
            }
            hp
                    .__escape(']')
                    ._SMALL();
        }
        return true;
    }

    private static BdfHref balayageHref(String balayageName) {
        return BH.domain(Domains.EXPORTATION).page(ExportationDomain.BALAYAGE_RESULT_PAGE).command(BalayageRunCommand.COMMANDNAME).pageErr(ExportationDomain.BALAYAGE_ERROR_PAGE).balayage(balayageName);
    }

}
