/* BdfServer_HtmlProducers - Copyright (c) 2010-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.sphere;

import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.SphereDomain;
import fr.exemole.bdfserver.html.BdfHtmlConstants;
import fr.exemole.bdfserver.html.consumers.Button;
import fr.exemole.bdfserver.html.consumers.SubsetIcon;
import fr.exemole.bdfserver.tools.BH;
import fr.exemole.bdfserver.tools.BdfHref;
import net.fichotheque.sphere.Redacteur;
import net.fichotheque.sphere.Sphere;
import net.fichotheque.utils.SphereUtils;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlPrinter;


/**
 *
 * @author Vincent Calame
 */
public final class SphereHtmlUtils {

    private SphereHtmlUtils() {
    }

    public static boolean printSphereToolbar(HtmlPrinter hp, String pageActu, Sphere sphere) {
        hp
                .NAV("subset-Toolbar")
                .DIV("subset-Buttons")
                .SPAN("subset-SmallLabel")
                .__localize("_ title.global.commands")
                .__colon()
                ._SPAN()
                .__(printLink(hp, "action-Metadata", sphere, SphereDomain.SPHERE_METADATAFORM_PAGE, "_ link.sphere.spheremetadataform", pageActu))
                .__(printLink(hp, "action-Advanced", sphere, SphereDomain.SPHERE_ADVANCEDCOMMANDS_PAGE, "_ link.sphere.sphereadvancedcommands", pageActu))
                .__(printRefresh(hp, sphere))
                ._DIV()
                ._NAV();
        return true;
    }

    public static boolean printRedacteurToolbar(HtmlPrinter hp, String pageActu, Redacteur redacteur) {
        hp
                .HEADER("subset-ItemHeader")
                .H1()
                .__(SubsetIcon.SPHERE)
                .__escape(SphereUtils.toBracketStyle(redacteur))
                .__dash()
                .__escape(SphereUtils.toCompleteName(redacteur))
                ._H1()
                ._HEADER();
        hp
                .NAV("subset-Toolbar")
                .DIV("subset-Buttons")
                .SPAN("subset-SmallLabel")
                .__localize("_ title.global.commands")
                .__colon()
                ._SPAN()
                .__(printLink(hp, "action-RedacteurEdit", redacteur, SphereDomain.REDACTEUR_ADMINFORM_PAGE, "_ link.sphere.redacteuradminform", pageActu))
                .__(printLink(hp, "action-RedacteurState", redacteur, SphereDomain.REDACTEUR_STATE_PAGE, "_ link.sphere.redacteurstate", pageActu))
                .__(printLink(hp, "action-Advanced", redacteur, SphereDomain.REDACTEUR_ADVANCEDCOMMANDS_PAGE, "_ link.sphere.redacteuradvancedcommands", pageActu))
                .__(printRefresh(hp, redacteur.getSphere()))
                ._DIV()
                ._NAV();
        return true;
    }

    public static boolean printLink(HtmlPrinter hp, String action, Object object, String page, String titleLocKey, String pageActu) {
        if (pageActu.equals(page)) {
            hp
                    .SPAN("global-button-Transparent global-button-Current " + action)
                    .__(Button.ICON)
                    ._SPAN();
        } else {
            BdfHref href = BH.domain(Domains.SPHERE).page(page);
            if (object instanceof Sphere) {
                href.subset((Sphere) object);
            } else if (object instanceof Redacteur) {
                href.subsetItem((Redacteur) object);
            }
            hp
                    .A(HA.href(href).titleLocKey(titleLocKey).classes("global-button-Transparent " + action))
                    .__(Button.ICON)
                    ._A();
        }
        return true;
    }

    private static boolean printRefresh(HtmlPrinter hp, Sphere sphere) {
        hp
                .A(HA
                        .href(BH.domain(Domains.SPHERE).page(SphereDomain.SPHERE_PAGE).subset(sphere))
                        .titleLocKey("_ link.global.reload")
                        .classes("global-button-Transparent action-Refresh")
                        .target(BdfHtmlConstants.LIST_FRAME))
                .__(Button.ICON)
                ._A();
        return true;
    }

}
