/* global BDF,Ficheform,$$ */

Ficheform.AddendaInclude = {};

Ficheform.AddendaInclude.NOCHANGE_STATE = "nochange";
Ficheform.AddendaInclude.UPDATE_STATE = "update";
Ficheform.AddendaInclude.REMOVE_STATE = "remove";
Ficheform.AddendaInclude.CREATE_STATE = "create";
Ficheform.AddendaInclude.DOCUMENT_CHANGETYPE = "document";
Ficheform.AddendaInclude.CREATION_CHANGETYPE = "creation";

Ficheform.AddendaInclude.Document = function () {
};

Ficheform.AddendaInclude.Creation = function () {
};

Ficheform.AddendaInclude.Utils = function () {
};

Ficheform.AddendaInclude.init = function () {
    BDF.$({ficheformRole: "document-file"}).find("input").change(Ficheform.AddendaInclude.testFileInputChange);
    BDF.$({ficheformEntry: "addenda-include"}).each(function (index, element) {
        let $entry = $(element);
        let entryKey = $entry.data("ficheformKey");
        let addendaName = BDF.getSubsetName($entry);
        Ficheform.AddendaInclude.checkHidden($entry);
        BDF.$($entry, {ficheformRole: "document"}).each(function (index2, documentDiv) {
            let documentDivId = documentDiv.id;
            var $documentDiv = $(documentDiv);
            $documentDiv.append(BDF.render("ficheform:addenda-document", {
                documentDivId: documentDivId,
                noTab: Ficheform.getOption("noTab")
            }));
            _initDocumentInfo(addendaName, $documentDiv);
            $$(documentDivId, "change").click(function () {
                Ficheform.AddendaInclude.Document.openChange(entryKey, documentDivId);
            });
            $$(documentDivId, "remove").click(function () {
                Ficheform.AddendaInclude.Document.remove(entryKey, documentDivId);
            });
            $$(documentDivId, "restore").click(function () {
                Ficheform.AddendaInclude.Document.restore(entryKey, documentDivId);
            });
        });
        let createButtonId = BDF.generateId();
        BDF.$($entry, {ficheformRole: "document-input"}).append(BDF.render("ficheform:addenda-create", {
            buttonId: createButtonId,
            noTab: Ficheform.getOption("noTab")
        }));
        $$(createButtonId).click(function () {
            Ficheform.AddendaInclude.Creation.openNew(entryKey);
        });
    });
    
    
    function _initDocumentInfo(addendaName, $documentDiv) {
        var documentInfo = {
            subsetName: addendaName,
            itemId: BDF.getSubsetItemId($documentDiv)
        };
        $documentDiv.data("documentInfo", documentInfo);
    }
    
};

Ficheform.AddendaInclude.checkHidden = function ($entry) {
    let $documentList = BDF.$($entry, {ficheformRole: "document-list"});
    if ($documentList.find("*").length === 0) {
        $documentList.addClass("hidden");
    }
};

Ficheform.AddendaInclude.testFileInputChange = function () {
    var $parent = $(this).parent();
    var isFull = true;
    var $fileInputList = $parent.find("input");
    for(var i = 0; i < $fileInputList.length; i++) {
        var fileInput = $fileInputList[i];
        if (fileInput.files.length === 0) {
            isFull = false;
        }
    }
    if (isFull) {
        var texte = '<input type="file" class="ficheform-Full global-FileInput TEMPORARY" name="' + this.name + '" size="70" multiple>';
        $parent.append(texte);
    }
    $parent.find("input.TEMPORARY").change(Ficheform.AddendaInclude.testFileInputChange).removeClass("TEMPORARY");
};


/** Document ***************************************************************************/

Ficheform.AddendaInclude.Document.openChange = function (entryKey, documentDivId) {
    var $entry = Ficheform.$entry(entryKey);
    var addendaName = BDF.getSubsetName($entry);
    var $documentDiv = $$(documentDivId);
    var appelant = entryKey + "/" + documentDivId;
    BDF.putAppelantCallback(appelant, _callbackChange);
    var documentInfo = $documentDiv.data("documentInfo");
    var url = "addenda?page=document-change&addenda=" + addendaName + "&changetype=" + Ficheform.AddendaInclude.DOCUMENT_CHANGETYPE + "&appelant=" + appelant + "&id=" + documentInfo.itemId;
    if (documentInfo.changeParameter) {
        url = url + "&change=" + encodeURIComponent(documentInfo.changeParameter);
    }
    Ficheform.openDialog(url,"pioche_"+ entryKey, 620, 580);
    
    
    function _callbackChange(appelantResponse) {
        let $field = BDF.$($entry, {ficheformRole: "changefield"});
        let newVal = Ficheform.removeFromValue($field.val(), documentInfo.itemId, ":");
        let appelantResponseString = Ficheform.AddendaInclude.Document.appelantResponseToString(appelantResponse);
        documentInfo.changeParameter = appelantResponseString;
        if (appelantResponseString.length > 0) {
            newVal = newVal + documentInfo.itemId + ":" + appelantResponseString + ";";
        }
        $field.val(newVal);
        Ficheform.AddendaInclude.Utils.updateExtensions(appelantResponse, entryKey, documentDivId);
        Ficheform.signalChange();
    }
};


Ficheform.AddendaInclude.Document.remove = function (entryKey, documentDivId) {
    var ok = confirm(BDF.Loc.get("_ warning.edition.documentremove_existing"));
    if (ok) {
        let $entry = Ficheform.$entry(entryKey);
        let $documentDiv = $$(documentDivId).addClass("ficheform-document-Removed");
        BDF.$($documentDiv, {showState: "active"}).addClass("hidden");
        BDF.$($documentDiv, {showState: "restore"}).removeClass("hidden");
        let documentInfo = $documentDiv.data("documentInfo");
        let $field = BDF.$($entry, {ficheformRole: "removefield"});
        $field.val($field.val() + documentInfo.itemId + ";");
        Ficheform.signalChange();
    }
};

Ficheform.AddendaInclude.Document.restore = function (entryKey, documentDivId) {
    var $entry = Ficheform.$entry(entryKey);
    var $documentDiv = $$(documentDivId).removeClass("ficheform-document-Removed");
    BDF.$($documentDiv, {showState: "active"}).removeClass("hidden");
    BDF.$($documentDiv, {showState: "restore"}).addClass("hidden");
    var $field = BDF.$($entry, {ficheformRole: "removefield"});
    var documentInfo = $documentDiv.data("documentInfo");
    $field.val(Ficheform.removeFromValue($field.val(), documentInfo.itemId));
    Ficheform.signalChange();
};

Ficheform.AddendaInclude.Document.appelantResponseToString = function (appelantResponse) {
    var extensionMap = appelantResponse.extensionMap;
    var text = "";
    for(let extension in extensionMap) {
        let extensionObj = extensionMap[extension];
        let state = extensionObj.state;
        if (state === Ficheform.AddendaInclude.REMOVE_STATE) {
            if (extensionObj.previousState !== Ficheform.AddendaInclude.CREATE_STATE) {
                text += "re=" + extension + ",";
            }
        } else if ((state === Ficheform.AddendaInclude.UPDATE_STATE) || (state === Ficheform.AddendaInclude.CREATE_STATE)) {
            text += "tf=" + extensionObj.tmpFileName + ",";
        }
    }
    if (appelantResponse.basename) {
        text += "bn=" + appelantResponse.basename;
    }
    return text;
};


/** Creation ***************************************************************************/

Ficheform.AddendaInclude.Creation.creationMap = new Object();

Ficheform.AddendaInclude.Creation.remove = function (entryKey, documentDivId) {
    var ok = confirm(BDF.Loc.get("_ warning.edition.documentremove_creation"));
    if (ok) {
        Ficheform.AddendaInclude.Creation.removeCreationInfo(entryKey, documentDivId);
        $$(documentDivId).remove();
        Ficheform.AddendaInclude.checkHidden(Ficheform.$entry(entryKey));
        Ficheform.signalChange();
    }
};

Ficheform.AddendaInclude.Creation.openNew = function (entryKey) {
    var $entry = Ficheform.$entry(entryKey);
    var addendaName = BDF.getSubsetName($entry);
    var appelant = entryKey;
    BDF.putAppelantCallback(appelant, _callback);
    var url = "addenda?page=document-upload-new&addenda=" + addendaName  + "&appelant=" + appelant;
    Ficheform.openDialog(url, "pioche_" + entryKey, 620, 580);
    
    
    function _callback(appelantResponse) {
        let extensionMap = appelantResponse.extensionMap;
        let extensionText = "";
        let next = false;
        for(let extension in extensionMap) {
            let extensionObj = extensionMap[extension];
            let state = extensionObj.state;
            if ((state === Ficheform.AddendaInclude.UPDATE_STATE) || (state === Ficheform.AddendaInclude.CREATE_STATE)) {
                if (next) {
                    extensionText += " / ";
                } else {
                    next = true;
                }
                extensionText += "." + extension;
            }
        }
        let documentDivId = BDF.generateId();
        BDF.$($entry, {ficheformRole: "document-list"}).append(BDF.render("ficheform:addenda-new", {
            documentDivId: documentDivId,
            basename: appelantResponse.basename,
            extensionText: extensionText,
            noTab: Ficheform.getOption("noTab")
        })).removeClass("hidden");
        $$(documentDivId, "change").click(function () {
            Ficheform.AddendaInclude.Creation.openChange(entryKey, documentDivId);
        });
        $$(documentDivId, "remove").click(function () {
            Ficheform.AddendaInclude.Creation.remove(entryKey, documentDivId);
        });
        Ficheform.AddendaInclude.Creation.addCreationInfo(entryKey, documentDivId, Ficheform.AddendaInclude.Utils.appelantResponseToString(appelantResponse), appelantResponse.originalName);
        Ficheform.signalChange();
    }
};

Ficheform.AddendaInclude.Creation.openChange = function (entryKey, documentDivId) {
    var $entry = Ficheform.$entry(entryKey);
    var addendaName = BDF.getSubsetName($entry);
    var appelant = entryKey + "/" + documentDivId;
    BDF.putAppelantCallback(appelant, _callback);
    var creationInfo = Ficheform.AddendaInclude.Creation.getCreationInfo(entryKey, documentDivId);
    var url = "addenda?page=document-change&addenda=" + addendaName + "&changetype=" + Ficheform.AddendaInclude.CREATION_CHANGETYPE + "&appelant=" + appelant
        + "&originalname=" + encodeURIComponent(creationInfo.originalName)
        + "&change=" + encodeURIComponent(creationInfo.changeParameter);
    Ficheform.openDialog(url,"pioche_"+ entryKey, 620, 580);
    
    
    function _callback(appelantResponse) {
        creationInfo.changeParameter = Ficheform.AddendaInclude.Document.appelantResponseToString(appelantResponse);
        Ficheform.AddendaInclude.Utils.updateExtensions(appelantResponse, entryKey, documentDivId);
        Ficheform.AddendaInclude.Creation.updateInput(BDF.$($entry, {ficheformRole: "createfield"}));
        Ficheform.signalChange();
    }
};

Ficheform.AddendaInclude.Creation.appelantResponseToString = function (appelantResponse) {
    var extensionMap = appelantResponse.extensionMap;
    var text = appelantResponse.basename + ":";
    for(let extension in extensionMap) {
        let extensionObj = extensionMap[extension];
        let state = extensionObj.state;
        if ((state === Ficheform.AddendaInclude.UPDATE_STATE) || (state === Ficheform.AddendaInclude.CREATE_STATE)) {
            text += extensionObj.tmpFileName + ",";
        }
    }
    return text;
};

Ficheform.AddendaInclude.Creation.removeCreationInfo = function (entryKey, documentDivId) {
    var $entry = Ficheform.$entry(entryKey);
    var $field = BDF.$($entry, {ficheformRole: "createfield"});
    var creationArray = $field.data("creationArray");
    Ficheform.AddendaInclude.Creation.updateInput($field);
    if (creationArray) {
        let length = creationArray.length;
        for(let i = 0; i < length; i++) {
            if (creationArray[i].id === documentDivId) {
                if (i === (length - 1)) {
                    creationArray.pop();
                } else {
                    creationArray.splice(i,1);
                    break;
                }
            }
        }
        Ficheform.AddendaInclude.Creation.updateInput($field);
    }    
};

Ficheform.AddendaInclude.Creation.getCreationInfo = function (entryKey, documentDivId) {
    var $entry = Ficheform.$entry(entryKey);
    var $field = BDF.$($entry, {ficheformRole: "createfield"});
    Ficheform.AddendaInclude.Creation.updateInput($field);
    var creationArray = $field.data("creationArray");
    if (creationArray) {
        for(let creation of creationArray) {
            if (creation.id === documentDivId) {
                return creation;
            }
        }
    }
    return null;    
};

Ficheform.AddendaInclude.Creation.addCreationInfo = function (entryKey, documentDivId, changeParameter, originalName) {
    var $entry = Ficheform.$entry(entryKey);
    var $field = BDF.$($entry, {ficheformRole: "createfield"});
    var obj = {id: documentDivId, changeParameter: changeParameter, originalName: originalName};
    var creationArray = $field.data("creationArray");
    if (!creationArray) {
        creationArray = new Array();
        creationArray[0] = obj;
        $field.data("creationArray", creationArray);
    } else {
        creationArray.push(obj);
    }
    Ficheform.AddendaInclude.Creation.updateInput($field);
    return obj;
};

Ficheform.AddendaInclude.Creation.updateInput = function ($field) {
    var creationArray = $field.data("creationArray");
    if (!creationArray) {
        $field.val("");
        return;
    }
    var text = "";
    for(let creation of creationArray) {
        text += creation.changeParameter;
        text += ";";
    }
    $field.val(text);
    Ficheform.signalChange();
};


/** Utils ***************************************************************************/

Ficheform.AddendaInclude.Utils.appelantResponseToString = function (appelantResponse) {
    var extensionMap = appelantResponse.extensionMap;
    var text = "";
    for(let extension in extensionMap) {
        let extensionObj = extensionMap[extension];
        let state = extensionObj.state;
        if (state === Ficheform.AddendaInclude.REMOVE_STATE) {
            if (extensionObj.previousState !== Ficheform.AddendaInclude.CREATE_STATE) {
                text += "re=" + extension + ",";
            }
        } else if ((state === Ficheform.AddendaInclude.UPDATE_STATE) || (state === Ficheform.AddendaInclude.CREATE_STATE)) {
            text += "tf=" + extensionObj.tmpFileName + ",";
        }
    }
    if (appelantResponse.basename) {
        text += "bn=" + appelantResponse.basename;
    }
    return text;
};

Ficheform.AddendaInclude.Utils.updateExtensions = function (appelantResponse, entryKey, documentDivId) {
    var $entry = Ficheform.$entry(entryKey);
    var addenda = BDF.getSubsetName($entry);
    var $document = $$(documentDivId);
    if (appelantResponse.basename) {
        var $basename = BDF.$($document, {ficheformRole: "document-basename"});
        $basename.html(appelantResponse.basename);
        if (appelantResponse.changeType === Ficheform.AddendaInclude.DOCUMENT_CHANGETYPE) {
            $basename.addClass("ficheform-document-NameChanged");
        }
    }
    var extensionMap = appelantResponse.extensionMap;
    var extensionArray = new Array();
    for(let extension in extensionMap) {
        let extensionObj = extensionMap[extension];
        let cssClass, href;
        let state = extensionObj.state;
        if (state === Ficheform.AddendaInclude.UPDATE_STATE) {
            href = BDF.toTmpPath(extensionObj.tmpFileName);
            cssClass = "ficheform-document-VersionChanged";
        } else if (state === Ficheform.AddendaInclude.CREATE_STATE) {
            href =  BDF.toTmpPath(extensionObj.tmpFileName);
            cssClass = "ficheform-document-VersionAdded";
        } else if (state === Ficheform.AddendaInclude.REMOVE_STATE) {
            if (extensionObj.previousState === Ficheform.AddendaInclude.CREATE_STATE) {
                continue;
            }
            if (extensionObj.tmpFileName) {
                href =  BDF.toTmpPath(extensionObj.tmpFileName);
            } else {
                href = "documents/" + addenda + "/" + extensionObj.currentFileName;
            }
            cssClass = "ficheform-document-VersionRemoved";
        } else {
            href = "documents/" + addenda + "/"  + extensionObj.currentFileName;
            cssClass = false;
        }
        extensionArray.push({
            href: href,
            cssClass: cssClass,
            extension: extension
        });
    }
    BDF.$($document, {ficheformRole: "document-extensions"}).html(BDF.render("ficheform:addenda-extensions", {
        extensionArray: extensionArray,
        noTab: Ficheform.getOption("noTab")
    }));
    Ficheform.signalChange();
};