/* global BDF,$$,Resource,Overlay */

Resource.List = {};

Resource.List.init = function (callback) {
    BDF.Ajax.loadResourceTree(function (resourceTree) {
        Resource.completeFolderArrays(resourceTree);
        let $treeBlock = $$("listpane_treeblock");
        $treeBlock.html(BDF.render("resource:list-tree", resourceTree));
        Resource.List.initActions();
        BDF.Deploy.init($treeBlock);
        if (callback) {
            callback();
        }
    });
};

Resource.List.initActions = function () {
    $$("listpane_button_newresource").click(Resource.Overlay.showCreationForm);
     $$("listpane_button_newapp").click(Resource.Overlay.showNewAppForm);
    var $body = $$("listpane_treeblock");
    BDF.onClick($body, {action: "load-main"}, function () {
        if (!BDF.confirmUnload()) {
            return false;
        }
        let $reference = BDF.$parents($(this), {role: "content-reference"});
        BDF.Pane.loadOrDestock($reference.data("contentKey"), function () {
            _loadContent($reference, false);
        });
        return false;
    });
    
    
    function _loadContent($reference, isInStock) {
        let path = $reference.data("path");
        let linkType = $reference.data("linkType");
        if (linkType === "text") {
            let overlayId = BDF.startRunningOverlay();
            BDF.Ajax.loadStreamText(path, function (streamText) {
                Resource.Form.load(streamText, isInStock);
                Overlay.end(overlayId);
            });
        } else {
            Resource.Overlay.showResourceDisplay(linkType, path, $reference.data("origins"));
        }
        
    }

};

Resource.List.update = function (callback) {
    BDF.Ajax.loadResourceTree(function (resourceTree) {
        var $tree = BDF.$children($$("listpane_treeblock"), {role: "tree"});
        Resource.completeFolderArrays(resourceTree);
        Resource.List.compareFolder($tree, resourceTree);
        BDF.Deploy.init($tree);
        if (callback) {
            callback();
        }
    });
};

Resource.List.compareFolder = function ($list, newFolderObject) {
    var $currentSubfolders =  BDF.$children($list, {role: "folder"});
    var $currentResources = BDF.$children($list, {role: "content-reference"});
    var newSubfolderLength = newFolderObject.subfolderArray.length;
    if (newSubfolderLength === 0) {
        $currentSubfolders.remove();
    } else {
        let currentLength = $currentSubfolders.length;
        let p = 0;
        for(let i = 0; i < newSubfolderLength; i++) {
            let newSubfolder = newFolderObject.subfolderArray[i];
            let newName = newSubfolder.name;
            while(true) {
                if (p >= currentLength) {
                    _appendNewFolder(BDF.render("resource:list-folder", newSubfolder));
                    break;
                } else {
                    let $currentSubfolder = $($currentSubfolders[p]);
                    let currentName = $currentSubfolder.data("name");
                    if (newName === currentName) {
                        _updateFolder($currentSubfolder, newSubfolder);
                        p++;
                        break;
                    } else if (newName < currentName) {
                        $currentSubfolder.before(BDF.render("resource:list-folder", newSubfolder));
                        break;
                    } else {
                        $currentSubfolder.remove();
                        p++;
                    }
                }
            }
        }
        if (p < currentLength) {
            for(let i = p; i < currentLength; i++) {
                 $($currentSubfolders[i]).remove();
            }
        }
    }
    var newResourceLength = newFolderObject.resourceArray.length;
    if (newResourceLength === 0) {
        $currentResources.remove();
    } else {
        let currentLength = $currentResources.length;
        let p = 0;
        for(let i = 0; i < newResourceLength; i++) {
            let newResource = newFolderObject.resourceArray[i];
            let newName = newResource.name;
            while(true) {
                if (p >= currentLength) {
                    $list.append(BDF.render("resource:list-resource", newResource));
                    break;
                } else {
                    let $currentResource = $($currentResources[p]);
                    let currentName = $currentResource.data("name");
                    if (newName === currentName) {
                        _updateResourceElement($currentResource, newResource);
                        p++;
                        break;
                    } else if (newName < currentName) {
                        $currentResource.before(BDF.render("resource:list-resource", newResource));
                        break;
                    } else {
                        $currentResource.remove();
                        p++;
                    }
                }
            }
        }
        if (p < currentLength) {
            for(let i = p; i < currentLength; i++) {
                 $($currentResources[i]).remove();
            }
        }
    }
    
    
    function _appendNewFolder(html) {
        if ($currentResources.length > 0) {
            $($currentResources[0]).before(html);
        } else {
            $list.append(html);
        }
    }
    
    function _updateFolder($folder, folderObject) {
        let origins = Resource.originsToString(folderObject);
        let $folderTitle = BDF.$($folder, {role: "folder-title", name: folderObject.name});
        $folderTitle.removeClass(function (index, className) {
            let result = /resource-origin-([a-zA-Z]+)/.exec(className);
            if (result) {
                return result[0];
            } else {
                return "";
            }
        });
        $folderTitle.addClass(Resource.getMatchingClass(origins));
        let $folderContent = BDF.$($folder, {role: "folder-content", name: folderObject.name});
        Resource.List.compareFolder($folderContent, folderObject);
    };
    
    function _updateResourceElement($resource, resourceObject) {
        let origins = Resource.originsToString(resourceObject);
        $resource.attr("data-origins", origins);
        $resource.data("origins", origins);
        $resource.removeClass(function (index, className) {
            let result = /resource-origin-([a-zA-Z]+)/.exec(className);
            if (result) {
                return result[0];
            } else {
                return "";
            }
        });
        $resource.addClass(Resource.getMatchingClass(origins));
    };
    
};