/* FichothequeLib_API - Copyright (c) 2019-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.utils;

import java.util.AbstractList;
import java.util.Collections;
import java.util.List;
import java.util.RandomAccess;
import net.fichotheque.exportation.transformation.TemplateContentDescription;
import net.fichotheque.exportation.transformation.TemplateDescription;
import net.fichotheque.exportation.transformation.TransformationDescription;
import net.fichotheque.exportation.transformation.TransformationKey;


/**
 *
 * @author Vincent Calame
 */
public final class TransformationUtils {

    public final static List<TemplateDescription> EMPTY_TEMPLATEDESCRIPTIONLIST = Collections.emptyList();

    private TransformationUtils() {

    }

    public static boolean isUseableTemplateState(String state) {
        switch (state) {
            case TemplateDescription.OK_STATE:
            case TemplateDescription.WITH_WARNINGS_STATE:
                return true;
            default:
                return false;
        }
    }

    public static TransformationDescription getEmptyTransformationDescription(TransformationKey transformationKey) {
        return new EmptyTransformationDescription(transformationKey);
    }

    public static List<TemplateDescription> wrap(TemplateDescription[] array) {
        return new TemplateDescriptionList(array);
    }

    public static List<TemplateContentDescription> wrap(TemplateContentDescription[] array) {
        return new TemplateContentList(array);
    }


    private static class EmptyTransformationDescription implements TransformationDescription {

        private final TransformationKey transformationKey;

        private EmptyTransformationDescription(TransformationKey transformationKey) {
            this.transformationKey = transformationKey;
        }

        @Override
        public TransformationKey getTransformationKey() {
            return transformationKey;
        }

        @Override
        public List<TemplateDescription> getSimpleTemplateDescriptionList() {
            return EMPTY_TEMPLATEDESCRIPTIONLIST;
        }

        @Override
        public List<TemplateDescription> getStreamTemplateDescriptionList() {
            return EMPTY_TEMPLATEDESCRIPTIONLIST;
        }

    }


    private static class TemplateDescriptionList extends AbstractList<TemplateDescription> implements RandomAccess {

        private final TemplateDescription[] array;

        private TemplateDescriptionList(TemplateDescription[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public TemplateDescription get(int index) {
            return array[index];
        }

    }


    private static class TemplateContentList extends AbstractList<TemplateContentDescription> implements RandomAccess {

        private final TemplateContentDescription[] array;

        private TemplateContentList(TemplateContentDescription[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public TemplateContentDescription get(int index) {
            return array[index];
        }

    }

}
