/* FichothequeLib_Tools - Copyright (c) 2008-2016 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.conversion.fieldtofield;

import net.fichotheque.corpus.fiche.Fiche;
import net.fichotheque.corpus.fiche.FicheItem;
import net.fichotheque.corpus.fiche.Item;
import net.fichotheque.corpus.fiche.Langue;
import net.fichotheque.corpus.metadata.FieldKey;
import net.fichotheque.utils.FicheUtils;
import net.mapeadores.util.exceptions.SwitchException;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.logging.MultiMessageHandler;


/**
 *
 * @author Vincent Calame
 */
class SimpleToFicheItemField extends FieldToFieldConverter {

    private final FieldKey destinationKey;
    private final FieldKey sourceKey;

    SimpleToFicheItemField(FieldKey sourceKey, FieldKey destinationKey, MultiMessageHandler messageHandler) {
        super(messageHandler);
        this.destinationKey = destinationKey;
        this.sourceKey = sourceKey;
    }

    @Override
    void convertContent(Fiche fiche, boolean removeOldField) {
        FicheItem ficheItem = getFicheItem(fiche);
        if (ficheItem == null) {
            return;
        }
        if (destinationKey.isProprieteFieldKey()) {
            fiche.setPropriete(destinationKey, ficheItem);
        } else {
            fiche.appendInformation(destinationKey, FicheUtils.toFicheItems(ficheItem));
        }
        if (removeOldField) {
            if (sourceKey.equals(FieldKey.SOUSTITRE)) {
                fiche.setSoustitre(null);
            } else if (sourceKey.equals(FieldKey.TITRE)) {
                fiche.setTitre("");
            }
        }
    }

    private FicheItem getFicheItem(Fiche fiche) {
        if (sourceKey.equals(FieldKey.TITRE)) {
            return getItem(fiche.getTitre());
        } else if (sourceKey.equals(FieldKey.SOUSTITRE)) {
            return fiche.getSoustitre();
        } else if (sourceKey.equals(FieldKey.LANG)) {
            Lang lang = fiche.getLang();
            if (lang != null) {
                return new Langue(lang);
            } else {
                return null;
            }
        } else {
            throw new SwitchException("sourceKey = " + sourceKey.toString());
        }
    }

    private Item getItem(String s) {
        if (s.length() == 0) {
            return null;
        }
        return new Item(s);
    }

}
