/* FichothequeLib_Tools - Copyright (c) 2016-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.corpus;

import java.text.ParseException;
import java.util.Collection;
import java.util.LinkedHashMap;
import java.util.Map;
import net.fichotheque.corpus.metadata.FieldGenerationDef;
import net.fichotheque.corpus.metadata.FieldKey;
import net.fichotheque.exportation.table.FormatColDef;
import net.fichotheque.exportation.table.TableDef;
import net.fichotheque.exportation.table.TableDefItem;
import net.fichotheque.format.FichothequeFormatDef;
import net.fichotheque.tools.exportation.table.TableDefParser;
import net.mapeadores.util.logging.LineMessageHandler;


/**
 *
 * @author Vincent Calame
 */
public class FieldGenerationDefParser {

    private final Map<FieldKey, FieldGenerationDef> map = new LinkedHashMap<FieldKey, FieldGenerationDef>();

    private FieldGenerationDefParser() {

    }

    private void innerParse(String fieldGenerationSource, LineMessageHandler lineMessageHandler) {
        TableDef tableDef = TableDefParser.parse(fieldGenerationSource, lineMessageHandler, 0);
        for (TableDefItem defItem : tableDef.getDefItemList()) {
            if (defItem instanceof FormatColDef) {
                FormatColDef colDef = (FormatColDef) defItem;
                String colName = colDef.getColName();
                try {
                    FieldKey fieldKey = FieldKey.parse(colName);
                    if (!map.containsKey(fieldKey)) {
                        map.put(fieldKey, new InternalFieldGenerationDef(fieldKey, colDef.getFichothequeFormatDef()));
                    }
                } catch (ParseException pe) {

                }
            }
        }
    }

    public static Collection<FieldGenerationDef> parse(String fieldGenerationSource, LineMessageHandler lineMessageHandler) {
        FieldGenerationDefParser parser = new FieldGenerationDefParser();
        parser.innerParse(fieldGenerationSource, lineMessageHandler);
        return parser.map.values();
    }


    private static class InternalFieldGenerationDef implements FieldGenerationDef {

        private final FieldKey fieldKey;
        private final FichothequeFormatDef fichothequeFormatDef;

        private InternalFieldGenerationDef(FieldKey fieldKey, FichothequeFormatDef fichothequeFormatDef) {
            this.fieldKey = fieldKey;
            this.fichothequeFormatDef = fichothequeFormatDef;
        }

        @Override
        public FieldKey getFieldKey() {
            return fieldKey;
        }

        @Override
        public FichothequeFormatDef getFormatDef() {
            return fichothequeFormatDef;
        }

    }

}
